@@ -39,9 +39,7 @@ class SamTemplate:
             if needs_filter:
                 yield logicalId, resource
 
-    def set(  # noqa: builtin-attribute-shadowing
-        self, logical_id: str, resource: Union[SamResource, Dict[str, Any]]
-    ) -> None:
+    def set(self, logical_id: str, resource: Union[SamResource, Dict[str, Any]]) -> None:  # noqa: A003
         """
         Adds the resource to dictionary with given logical Id. It will overwrite, if the logical_id is already used.
 
@@ -55,6 +53,14 @@ class SamTemplate:
 
         self.resources[logical_id] = resource_dict
 
+    def get_globals(self) -> Dict[str, Any]:
+        """
+        Gets the global section of the template
+
+        :return dict: Global section of the template
+        """
+        return self.template_dict.get("Globals") or {}
+
     def get(self, logical_id: str) -> Optional[SamResource]:
         """
         Gets the resource at the given logical_id if present
